@@ -2,7 +2,9 @@
 
 extern crate wright;
 use wright::version::VERSION;
+use std::process::exit;
 
 fn main() {
     println!("Wright's liftoff installer and utility is not yet implemented as of version {}.", VERSION);
+    exit(1);
 }
\ No newline at end of file
